# `BioClients.pubmed`

## PubMed

* (PubMed)[https://pubmed.ncbi.nlm.nih.gov/]

Parse, process Entrez PubMed XML (summaries or full), normally obtained via
Entrez eUtils, eDirect CLI or Perl API.

Note that other Entrez XML (e.g. PubChem) very similar.
